import { buildUUID } from '../../../utils/uuid';
import { ApiAction, ApiActionPage } from '../../model/baseModel';
import {
  TransferPageListGetResultModel,
  TransferDetailPageListGetResultModel,
  TransferDetailSNPageListGetResultModel,
  TransferPageParams,
  TransferdtlPageParams,
  TransferdtlsnPageParams,
  TransferDetailListItem
} from '../model/warehoueseModel';
import { genAction, Api, genActionPage } from '../system';
import { useUserStore } from '/@/store/modules/user';
import { formatToDateTime } from '/@/utils/dateUtil';
import { defHttp } from '/@/utils/http/axios';
import { isNullOrEmpty } from '/@/utils/is';

/*
 * 获取调拨单分页列表
 */
export const getTransferListByPage = async (params: TransferPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And BILLCODE like '%" + params?.BILLCODE + "%'";
  }
  if (params?.BILLDATE != undefined && params?.BILLDATE != '') {
    sqlcmd += " And BILLDATE > '" + params?.BILLDATE[0] + "'";
  }
  if (!isNullOrEmpty(params?.BILLDATE)) {
    sqlcmd += " And BILLDATE < '" + params?.BILLDATE[1] + "'";
  }
  // if (!isNullOrEmpty(params?.STATUS)) {
  //   sqlcmd += " And STATUS = '" + params?.STATUS + "'";
  // }
  if (!isNullOrEmpty(params?.STATUS)) {
    sqlcmd += " And STATUS = '" + params?.STATUS + "'";
  }
  // if (params?.BILLDATE != undefined && params?.BILLDATE != '') {
  //   sqlcmd += "And BILLDATE like '%" + params?.BILLDATE + "%'";
  // }
  let option = {
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  if(!isNullOrEmpty(params.page)){
    const usParams = genAction('BIZ_WMS_TRANSFER', {
      QueryAble_T: '',
      where: sqlcmd,
      order: isNullOrEmpty(order)?'UPDATE_TIME desc':'UPDATE_TIME, '+order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    return getTransferListByPageAsync(usParams);
  }else{
    const usParams = genAction('BIZ_WMS_TRANSFER', {
      QueryAble_T: '',
      where: sqlcmd,
      option
    },option);
    return getTransferListByPageAsync(usParams);
  }
  // const rParams = genActionPage('BIZ_WMS_TRANSFER', sqlcmd, params.page, params.pageSize, option);
  // return getTransferListByPageAsync(rParams);
};
async function getTransferListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if(isNullOrEmpty(data.Data.page)){
     model = {
      items: data.Data.Items,
    };
  }else{
      model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  
  return model;
}
//单据详情
export const getTransferDetailListByPage = async (params: TransferdtlPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And BILLCODE like '%" + params?.BILLCODE + "%'";
  }
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE like '%" + params?.ITEM_CODE + "%'";
  }
  // if (params?.OUTWAREHOUSECODE != undefined && params?.OUTWAREHOUSECODE != '') {
  //   sqlcmd += " And OUTWAREHOUSECODE = '" + params?.OUTWAREHOUSECODE + "'";
  // }
  // if (params?.INWAREHOUSECODE != undefined && params?.INWAREHOUSECODE != '') {
  //   sqlcmd += " And INWAREHOUSECODE = '" + params?.INWAREHOUSECODE + "'";
  // }
  // if (!isNullOrEmpty(params?.LINESTATUS)) {
  //   sqlcmd += " And LINESTATUS = '" + params?.LINESTATUS + "'";
  // }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  // const rParams = genActionPage('BIZ_WMS_TRANSFER_DTL', sqlcmd, params.page, params.pageSize,option);

  if(!isNullOrEmpty(params.page)){
    const usParams = genAction('V_BIZ_WMS_TRANSFER_DTL', {
      QueryAble_T: '',
      where: sqlcmd,
      order: 'BILLLINE*1'+order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    return getTransferDetailListByPageAsync(usParams);
  }else{
    const usParams = genAction('V_BIZ_WMS_TRANSFER_DTL', {
      QueryAble_T: '',
      where: sqlcmd,
      option
    },option);
    return getTransferDetailListByPageAsync(usParams);
  }
};
async function getTransferDetailListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if(isNullOrEmpty(data.Data.page)){
     model = {
      items: data.Data.Items,
    };
  }else{
      model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  
  return model;
}
// async function getTransferDetailListByPageAsync(params: ApiActionPage) {
//   const data = await defHttp.post<ApiActionPage>(
//     { url: Api.EntityPageList, params },
//     {
//       isTransformResponse: false,
//     },
//   );
//   const model: TransferDetailPageListGetResultModel = {
//     items: data.Data.data,
//     total: data.Data.totals,
//   };
//   return model;
// }
//条码详情
export const getTransferDetailSNListByPage = async (params: TransferdtlsnPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE like '%" + params?.ITEM_CODE + "%'";
  }
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And BILLCODE  like '%" + params?.BILLCODE + "%'";
  }
  if (params?.SN != undefined && params?.SN != '') {
    sqlcmd += " And SN like '%" + params?.SN + "%'";
  }
  if (!isNullOrEmpty(params?.LINESTATUS)) {
    sqlcmd += " And LINESTATUS = '" + params?.LINESTATUS + "'";
  }
  // if (params?.BILLDATE != undefined && params?.BILLDATE != '') {
  //   sqlcmd += "And BILLDATE like '%" + params?.BILLDATE + "%'";
  // }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  if(!isNullOrEmpty(params.page)){
    const usParams = genAction('BIZ_WMS_TRANSFER_SN', {
      QueryAble_T: '',
      where: sqlcmd,
      order: order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    return getTransferDetailSNListByPageAsync(usParams);
  }else{
    const usParams = genAction('BIZ_WMS_TRANSFER_SN', {
      QueryAble_T: '',
      where: sqlcmd,
      option
    },option);
    return getTransferDetailSNListByPageAsync(usParams);
  }
  // const rParams = genActionPage('BIZ_WMS_TRANSFER_SN', sqlcmd, params.page, params.pageSize,option);
  // return getTransferDetailSNListByPageAsync(rParams);
};
async function getTransferDetailSNListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if(isNullOrEmpty(data.Data.page)){
     model = {
      items: data.Data.Items,
    };
  }else{
      model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  
  return model;
}
//保存
export const AddTransfer = async (params: any) => {
  let data;
  {
    params.ID = buildUUID(); //生成GUID
    params.CREATE_USER = useUserStore().getUserInfo.userId;
    params.UPDATE_USER = useUserStore().getUserInfo.userId;
    params.AUTH_ORG = useUserStore().getUserInfo.orgCode;
    params.UPDATE_TIME=formatToDateTime(new Date());
    const Transfer = {
      ID: params.ID,
      //SEQ_NO: params.SEQ_NO,
      CREATE_USER: params.CREATE_USER,
      UPDATE_USER: params.UPDATE_USER,
      UPDATE_TIME: params.UPDATE_TIME,
      BILLDATE:params.UPDATE_TIME,
      AUTH_ORG: params.AUTH_ORG,
      BILLCODE:params.BILLCODE,
      INWAREHOUSECODE:params.INWAREHOUSECODE,
      OUTWAREHOUSECODE:params.OUTWAREHOUSECODE,
      STATUS:params.STATUS,
      REMARK:params.REMARK,
      ERP_BILL_CODE:'不过帐'
    };
    data = await defHttp.post(
      { url: Api.AddEntity, params: genAction('BIZ_WMS_TRANSFER', Transfer) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  }
  return data;
}
export const AddTransferDtl = async (paramsDtl: any,params:any) => {
  let TransferDtls=[];
  let data;
  {
    paramsDtl.forEach(element => {
      const TransferDtl :TransferDetailListItem = {
        ID: element.ID,
        //SEQ_NO: params.SEQ_NO,
        CREATE_USER: element.CREATE_USER,
        UPDATE_USER: element.UPDATE_USER,
        UPDATE_TIME: formatToDateTime(new Date()),
        AUTH_ORG: element.AUTH_ORG,
        OUTWAREHOUSECODE:params.OUTWAREHOUSECODE,
        INWAREHOUSECODE:params.INWAREHOUSECODE,
        BILLCODE:params.BILLCODE,
        ITEM_CODE:element.ITEM_CODE,
        //ITEM_NAME:element.ITEM_NAME,
        BILLLINE:element.BILLLINE,
        // INQTY:params.INQTY,
        // OUTQTY:params.OUTQTY,
        PRQTY:element.PRQTY,
        UNITCODE:element.UNITCODE,
        ERP_BILL_CODE:'不过帐'
      };
      TransferDtls.push(TransferDtl)
    });
    
    data = await defHttp.post(
      { url: Api.AddListEntity, params: genAction('BIZ_WMS_TRANSFER_DTL', TransferDtls) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  }
  return data;
}
//生成调拨单单据
export const CreateBillCode = async () => {
  const data = await defHttp.get<any>(
    { url: Api.GetCreateTFBillCode },
    {
      isTransformResponse: false,
    },
  );
  return data.Data
}
//下拉列表
// STATUSs 单据状态
export const optionsListApi = async (params: Recordable) => {
  const usParams = genAction('BIZ_WMS_TRANSFER+STATUSs', '');
  var data = await defHttp.post(
    { url: Api.urlQueryEnum, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      // apiUrl: globSetting.taskApiUrl
    },
  );
  return data;
};
// export const optionTypeListApi = async (params: Recordable) => {
//   const usParams = genAction('BIZ_WMS_TRANSFER+BIZTYPEs', '');
//   return await defHttp.post(
//     { url: Api.urlQueryEnum, params: usParams },
//     {
//       errorMessageMode: 'none',
//       isTransformResponse: false,
//       // apiUrl: globSetting.taskApiUrl
//     },
//   );
// };